@@ -108,6 +108,8 @@ def json_default (obj):
     import datetime
     if isinstance(obj, datetime.datetime):
         return dt_serialize(obj)
+    if isinstance(obj, datetime.date):
+        return obj.strftime("%Y-%m-%d")
     if isinstance(obj, datetime.timedelta):
         return obj.total_seconds()
     import uuid
@@ -116,7 +118,7 @@ def json_default (obj):
     import decimal
     if isinstance(obj, decimal.Decimal):
         return float(obj)
-    raise TypeError("{!a} is not JSON serializable")
+    raise TypeError("{!a} is not JSON serializable".format(obj))
 
 
 
@@ -149,7 +151,7 @@ def logging_basic_config (logfile, level=logging.DEBUG):
     from os.path import abspath, dirname
     makedirs(dirname(abspath(logfile)), exist_ok=True)
     logging.Formatter.formatTime = _logging_format_time
-    logging.basicConfig(format="%(asctime)s %(levelname)s %(name)s %(thread)d %(msg)s", level=level, filename=logfile)
+    logging.basicConfig(format="%(asctime)s %(levelname)s %(name)s %(thread)d %(message)s", level=level, filename=logfile)
 
 def logging_adv_config (dir, name, file_level=logging.DEBUG, console_level=logging.INFO):
     from os import makedirs
@@ -168,10 +170,10 @@ def logging_adv_config (dir, name, file_level=logging.DEBUG, console_level=loggi
         "disable_existing_loggers": False,
         "formatters": {
             "full": {
-                "format": "%(asctime)s %(levelname)s %(name)s %(thread)d %(msg)s",
+                "format": "%(asctime)s %(levelname)s %(name)s %(thread)d %(message)s",
             },
             "simple": {
-                "format": "%(asctime)s %(levelname)s %(name)s %(msg)s",
+                "format": "%(asctime)s %(levelname)s %(name)s %(message)s",
                 "datefmt": "%Y-%m-%d %H:%M:%S",
             },
         },
